@@ -13,11 +13,10 @@ use English qw/ -no_match_vars /;
 use base qw/Exporter/;
 use Test::More;
 use Capture::Tiny qw/capture/;
-use Test::MockTime qw/restore_time set_fixed_time/;
 use App::Git::Workflow;
 use Mock::App::Git::Workflow::Repository;
 
-our $VERSION     = 0.96006;
+our $VERSION     = 0.96007;
 our @EXPORT      = qw/command_ok/;
 our @EXPORT_OK   = qw/command_ok/;
 our %EXPORT_TAGS = ();
@@ -60,10 +59,6 @@ sub command_ok ($$) {  ## no critic
         $data->{STD}{IN} ||= '';
         open $stdin, '<', \$data->{STD}{IN};
 
-        if ($data->{time}) {
-            set_fixed_time($data->{time});
-        }
-
         # run the code
         my $error;
         my ($stdout, $stderr) = capture { local *STDIN = $stdin; eval { $module->run() }; $error = $@; };
@@ -110,10 +105,6 @@ sub command_ok ($$) {  ## no critic
             or diag explain \%{"${module}::option"}, $data->{option};
         ok !@{ $git->{data} }, "All data setup is used"
             or diag explain $git->{data};
-
-        if ($data->{time}) {
-            restore_time();
-        }
     };
 }
 
@@ -127,7 +118,7 @@ Test::Git::Workflow::Command - Test Git::Workflow::Command::* files
 
 =head1 VERSION
 
-This documentation refers to Test::Git::Workflow::Command version 0.96006
+This documentation refers to Test::Git::Workflow::Command version 0.96007
 
 =head1 SYNOPSIS
 
